/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/**
 * @file
 * @date 09 Nov, 2020
 * @version 1.1.0
 *
 * @brief XMC1100 Boot kit blinky GPIO demo example
 *
 * The blinky example flashes the leds of the board with a periodic rate.
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 * Version 1.1.0 Use Board_LED library <br>
 *
 */

 
#include "Board_LED.h"
#include "xmc_common.h"

typedef enum {
	LED_STATE_OFF,
	LED_STATE_ON
} led_state_t;

void SysTick_Handler(void)
{
	static led_state_t led_state = LED_STATE_OFF;
	
	if (led_state == LED_STATE_OFF)
	{
    LED_On(0);
		led_state = LED_STATE_ON;
	}
	else
	{
    LED_Off(0);
		led_state = LED_STATE_OFF;
	}
}


int main(void)
{
	LED_Initialize();

  /* System timer configuration */
  SysTick_Config(SystemCoreClock >> 1);

  while(1)
  {
    /* Infinite loop */
  }
}
