/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/**
 * @file
 * @date 02 May, 2016
 * @version 1.0.0
 *
 * @brief XMC1200 Boot Kit RTX Blinky example
 *
 * Two threads are defined to switch on/off the LEDs in the board periodically
 *
 * History
 *
 * Version 1.0.0 
 * - Initial
 *
 */

#include "cmsis_os.h"
#include "xmc_gpio.h"

#define LED1 P0_0
#define LED2 P0_2
#define LED3 P0_5
#define LED4 P0_6
#define LED5 P0_7

/*----------------------------------------------------------------------------
 * blinkLED: blink LED and wait for signal to go to next LED
 *----------------------------------------------------------------------------*/
void blinkLED(void const *argument) 
{
  for (;;) 
	{
    XMC_GPIO_ToggleOutput(LED1);
    osSignalWait(0x0001, osWaitForever);
    XMC_GPIO_ToggleOutput(LED2);
    osSignalWait(0x0001, osWaitForever);
    XMC_GPIO_ToggleOutput(LED3);
    osSignalWait(0x0001, osWaitForever);
    XMC_GPIO_ToggleOutput(LED4);
    osSignalWait(0x0001, osWaitForever);
    XMC_GPIO_ToggleOutput(LED5);
    osSignalWait(0x0001, osWaitForever);
  }

}
osThreadId tid_blinkLED;
osThreadDef(blinkLED, osPriorityNormal, 1, 0);

/*----------------------------------------------------------------------------
 * mainThread: Switch on/off LEDs sequentially every 500ms
 *----------------------------------------------------------------------------*/
void mainThread(void const *argument) 
{
  for (;;) 
	{
    osDelay(500);
    osSignalSet(tid_blinkLED, 0x0001);
  }
}
osThreadId tid_mainThread;
osThreadDef(mainThread, osPriorityNormal, 1, 0);

__NO_RETURN int main(void)
{
	osKernelInitialize();
	
	/* Initialize peripherals */
	XMC_GPIO_SetMode(LED1, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
	XMC_GPIO_SetMode(LED2, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
  XMC_GPIO_SetMode(LED3, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
  XMC_GPIO_SetMode(LED4, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
  XMC_GPIO_SetMode(LED5, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
	
  /* create threads */
  tid_blinkLED = osThreadCreate(osThread(blinkLED), NULL);
	tid_mainThread = osThreadCreate(osThread(mainThread), NULL);
	
	osKernelStart();
	
	while(1);
}
