/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/*------------------------------------------------------------------------------
 * Name:    Main.c
 * Purpose: SPI Master Example
 *----------------------------------------------------------------------------*/
#include "Driver_SPI.h"
#include "xmc_common.h"

/* SPI Driver */
extern ARM_DRIVER_SPI Driver_SPI1;
static ARM_DRIVER_SPI * SPIdrv = &Driver_SPI1;

/* Data to be sent*/
static const uint8_t data_out[4] = {0x55, 0xAA, 0x55, 0xAA}; 

void mySPI_callback(uint32_t event)
{
	switch (event)
	{
	case ARM_SPI_EVENT_TRANSFER_COMPLETE:
			/* Success */
			SPIdrv->Send(&data_out, 1);
			break;
	
	case ARM_SPI_EVENT_MODE_FAULT:
			/*  Occurs in master mode when Slave Select is deactivated and
					indicates Master Mode Fault. */
			__BKPT(0);  /* Error: Call debugger or replace with custom error handling */
			break;
	}
}
 

int main(void)
{
	/*Initialize the SPI driver */
	SPIdrv->Initialize(mySPI_callback);
	/*Power up the SPI peripheral */
	SPIdrv->PowerControl(ARM_POWER_FULL);
	/*Configure the SPI */
	SPIdrv->Control(ARM_SPI_MODE_MASTER | ARM_SPI_DATA_BITS(32) | ARM_SPI_CPOL1_CPHA1 | ARM_SPI_SS_MASTER_HW_OUTPUT, 1000000);
	
	SPIdrv->Send(&data_out, 1);

	while (1)
	{
		;
	}
}
