/*
 * Copyright (c) 2013-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC1000 Series                                         **
**                                                                            **
** AUTHOR : Application Engineering Team                                      **
**                                                                            **
** version 1.0.0 						              **
**                                                                            **
** MODIFICATION DATE : Nov 04, 2013                                           **
**                                                                            **
*******************************************************************************/

/* NOTE: Only ES-AA sample is applicable, please replace the device on the    **
** current bootkit with ES-AA device  					      */





#include <XMC1300.h>		//SFR declarations of the selected device
#include "XMC1000_TSE.h"        // TSE library header
#include "GPIO.h"               // IO Control


uint8_t TSE_ISR_HIGH;           // Status for temp. High event
uint8_t TSE_ISR_LOW;            // Status for temp. Low event

__NO_RETURN int main(void)
{
	uint32_t temp_k = 0;            // Temperature in unit Kelvin
	uint32_t temp_C = 0;            // Temperature in unit Celcius
	uint32_t temp_High_k;           // Temperature High in unit Kelvin
	uint32_t temp_HighVar;          // Temperature High in register counter value
	uint32_t temp_Low_k;            // Temperature Low in unit Kelvin
	uint32_t temp_LowVar;           // Temperature Low in register counter value
	uint32_t delay = 10000;		      // Delay counter        

	SCU_GENERAL->PASSWD = 0x000000C0UL; // open access to protected bits
	SCU_CLK->CGATSET0 = 0x7FF;          // assert gating for all peripherals
	SCU_CLK->CLKCR = 0x3ff10100UL;	    // 32 MHz MCLK, 64 MHz PCLK
	SCU_GENERAL->PASSWD = 0x000000C3UL; // close access to protected bits
	SystemCoreClockUpdate();

	/* Enable global interrupt */
	__enable_irq();

	/* Enable SCU.SR1 interrupt */
	NVIC_EnableIRQ(SCU_1_IRQn);

	/* enable TSE */
	SCU_ANALOG->ANATSECTRL = 0x01;

	/* Set pins to output mode */
	P0_0_set_mode(OUTPUT_PP_GP);
	P0_1_set_mode(OUTPUT_PP_GP);
	P0_6_set_mode(OUTPUT_PP_GP);

	P0_0_set();		// Set P0.0
	P0_1_set();		// Set P0.1
	P0_6_set();		// Set P0.6        

	/* Set TSE High interrupt temperature  */
	temp_High_k = 85 + 273;                          // Convert 85�C to Kelvin
	temp_HighVar = XMC1000_CalcTSEVAR(temp_High_k);  // Convert from Kelvin to TSE counter value
	SCU_ANALOG->ANATSEIH = temp_HighVar;             // Insert temp High value to register ANATSEIH
	SET_BIT(SCU_INTERRUPT->SRMSK,SCU_INTERRUPT_SRMSK_TSE_HIGH_Pos);  // Enable temp high interrupt

	/* Set TSE Low interrupt temperature  */
	temp_Low_k = 0 + 273;                            // Convert 0�C to Kelvin
	temp_LowVar = XMC1000_CalcTSEVAR(temp_Low_k);    // Convert from Kelvin to TSE counter value
	SCU_ANALOG->ANATSEIL = temp_LowVar;              // Insert temp. Low value to register ANATSEIL
	SET_BIT(SCU_INTERRUPT->SRMSK,SCU_INTERRUPT_SRMSK_TSE_LOW_Pos);  // Enable temp Low interrupt

	while(1)
	{
		temp_k = XMC1000_CalcTemperature();  //Get temperature
		temp_C = temp_k - 273;
		if(temp_C == 25)
		{
			P0_0_set();	        // Set P0.0
			P0_1_reset();		    // Clear P0.1
			P0_6_set();		      // Set P0.6
		}
		else if (temp_C > 25)
		{
			P0_0_reset();		    // Clear P0.0
			P0_1_set();		      // Set P0.1
			P0_6_set();		      // Set P0.6
		}
		else if (temp_C < 25)
		{
			P0_0_set();		      // Clear P0.0
			P0_1_set();		      // Set P0.1
			P0_6_reset();		    // Set P0.6
		}

		/* Re-enable interrupt if temp. above the TSE_LOW */
		if(TSE_ISR_LOW == 1 && temp_C > 0)
		{
			SET_BIT(SCU_INTERRUPT->SRMSK,SCU_INTERRUPT_SRMSK_TSE_LOW_Pos);
			TSE_ISR_LOW = 0;
		}

		/* Re-enable interrupt if temp. above the TSE_HIGH */
		if(TSE_ISR_HIGH == 1 && temp_C < 85)
		{
			SET_BIT(SCU_INTERRUPT->SRMSK,SCU_INTERRUPT_SRMSK_TSE_HIGH_Pos);
			TSE_ISR_HIGH = 0;
		}
		while(--delay);
		delay = 10000;

	}
}

void SCU_1_IRQHandler (void)
{

	  /* TSE Compare High Event */
	  if(RD_REG(SCU_INTERRUPT->SRRAW,SCU_INTERRUPT_SRRAW_TSE_HIGH_Msk, SCU_INTERRUPT_SRRAW_TSE_HIGH_Pos))
	  {
		  /* clear the interrupt */
		  SCU_INTERRUPT->SRCLR |= SCU_INTERRUPT_SRCLR_TSE_HIGH_Msk;
		  /* disable interrupt */
		  CLR_BIT(SCU_INTERRUPT->SRMSK,SCU_INTERRUPT_SRMSK_TSE_HIGH_Pos);
		  TSE_ISR_HIGH = 1;

		  /* user code goes here... */
	  }
	  /* TSE Compare Low Event */
	  else if(RD_REG(SCU_INTERRUPT->SRRAW,SCU_INTERRUPT_SRRAW_TSE_LOW_Msk, SCU_INTERRUPT_SRRAW_TSE_LOW_Pos))
	  {
		  /* clear the interrupt */
		  SCU_INTERRUPT->SRCLR |= SCU_INTERRUPT_SRCLR_TSE_LOW_Msk;
		  /* disable interrupt */
		  CLR_BIT(SCU_INTERRUPT->SRMSK,SCU_INTERRUPT_SRMSK_TSE_LOW_Pos);
		  TSE_ISR_LOW = 1;

		  /* user code goes here... */
	  }
}



