/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/**
 * @file
 * @date 02 Jul, 2020
 * @version 1.2.0
 *
 * @brief XMC4200 Application Kit RTX5 Blinky example
 *
 * Two threads are defined:
 * - one blinking a LED1 every 500ms
 * - another sampling the BUTTON1 and stopping the LED1 blinking if the BUTTON1 is pressed
 *
 * History
 *
 * Version 1.0.0 
 * - Initial
 *
 * Version 1.1.0 
 * - Fix compilation warning when compiling with ARM Compiler 6 (armclang)
 *
 * Version 1.2.0
 * - Use Board support component
 * - Use CMSIS-RTOS Keil RTX component (IFX variant)
 */


#include "RTE_Components.h"
#include CMSIS_device_header

#include "Board_LED.h"
#include "Board_Buttons.h"

#include "cmsis_os2.h"

/*----------------------------------------------------------------------------
 * blinkLED: blink LED and wait for signal to go to next LED
 *----------------------------------------------------------------------------*/
__NO_RETURN void blinkLED(void *argument) 
{
  (void)argument;

  for (;;) 
  {
    LED_On(0);
    osThreadFlagsWait(0x0001, osFlagsWaitAny, osWaitForever);
    LED_Off(0);
    osThreadFlagsWait(0x0001, osFlagsWaitAny, osWaitForever);
  }
}

/*----------------------------------------------------------------------------
 * mainThread: Switch on/off LEDs sequentially every 500ms
 *----------------------------------------------------------------------------*/
__NO_RETURN void mainThread(void *argument) 
{
  (void)argument;

  osThreadId_t tid_blinkLED = osThreadNew(blinkLED, NULL, NULL);

  for (;;) 
  {
    osDelay(500);
    if ((Buttons_GetState() & 0x1) == 0)
    {
      osThreadFlagsSet(tid_blinkLED, 0x0001);
    }
  }
}

__NO_RETURN int main(void)
{		
  osKernelInitialize();
	
  LED_Initialize();
  Buttons_Initialize();
	
  /* create threads */
  osThreadNew(mainThread, NULL, NULL); // Create the app_main() launcher thread
	
  osKernelStart();

  while(1);
}
