/**
 * @file Buttons.c
 * @date 2019-09-16
 *
 * @cond
 *********************************************************************************************************************
 * Buttons interface for XMC4200 Platform2Go Kit v1.0
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *********************************************************************************************************************
 *
 * Change History
 * --------------
 *
 * 2019-09-16:
 *     - Initial version
 *
 * @endcond 
 *
 */

#include "xmc_gpio.h"
#include "Board_Buttons.h"

/* GPIO Pin identifier */
typedef struct _GPIO_PIN 
{
  XMC_GPIO_PORT_t *port;
  uint8_t         pin;
} GPIO_PIN;

/* LED GPIO Pins */
static const GPIO_PIN BUTTON_PIN[] = 
{
  { XMC_GPIO_PORT1, 15 }
};

#define BUTTON_COUNT (sizeof(BUTTON_PIN)/sizeof(GPIO_PIN))


/**
  \fn          int32_t Buttons_Initialize (void)
  \brief       Initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Initialize (void) 
{
  uint32_t n;
  XMC_GPIO_CONFIG_t gpio_config = 
	{
		.mode = XMC_GPIO_MODE_INPUT_INVERTED_TRISTATE
	};
	
  for (n = 0; n < BUTTON_COUNT; ++n) 
  {
    XMC_GPIO_Init(BUTTON_PIN[n].port, BUTTON_PIN[n].pin, &gpio_config);
  }

  return 0;
}

/**
  \fn          int32_t Buttons_Uninitialize (void)
  \brief       De-initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Uninitialize (void) 
{

  return 0;
}

/**
  \fn          uint32_t Buttons_GetState (void)
  \brief       Get buttons state
  \returns     Buttons state
*/
uint32_t Buttons_GetState (void) 
{
  uint32_t n;
  uint32_t val = 0;

  for (n = 0; n < BUTTON_COUNT; ++n) 
  {
    val |= XMC_GPIO_GetInput(BUTTON_PIN[n].port, BUTTON_PIN[n].pin) << n;
  }

  return val;
}

/**
  \fn          uint32_t Buttons_GetCount (void)
  \brief       Get number of available buttons
  \return      Number of available buttons
*/
uint32_t Buttons_GetCount (void) 
{
  return BUTTON_COUNT;
}
