/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: LED Flasher
 * Note(s): Blinky example for XMC4300
 *----------------------------------------------------------------------------
 * Blink LED connected with P4.0, P4.1
 * XMC4300 Relax kit
 *
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include <XMC4300.h>

const unsigned long led_mask[2] = {1UL << 0, 1UL << 1};      /*  GPIO P4.0, GPIO P4.1       */

void LED_Init(void);
void LED_On  (void);
void LED_Off (void);


volatile uint32_t msTicks;                      /* counts 1ms timeTicks       */
/*----------------------------------------------------------------------------
  SysTick_Handler
 *----------------------------------------------------------------------------*/
void SysTick_Handler(void) {
  msTicks++;
}

/*----------------------------------------------------------------------------
  delays number of tick Systicks (happens every 1 ms)
 *----------------------------------------------------------------------------*/
void Delay (uint32_t dlyTicks) {
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks) { __NOP(); }
}


/*----------------------------------------------------------------------------
  MAIN function
 *----------------------------------------------------------------------------*/
int main (void) {

  SystemCoreClockUpdate();                      /* update SystemCoreClock     */
  if (SysTick_Config(SystemCoreClock / 1000)) { /* SysTick 1 msec interrupts  */
    while (1) __NOP();                          /* Capture error              */
  }

  LED_Init();

  while(1) {                                 /* Loop forever      */

    LED_On ();                               /* Turn on LED'         */
    Delay(500);                              /* Delay 500ms       */
    LED_Off();                               /* Turn off LED '       */
    Delay(500);                              /* Delay 500ms       */

  }

}

/*----------------------------------------------------------------------------
  initialize LED Pins
 *----------------------------------------------------------------------------*/
void LED_Init (void) {

  /* configure PORT P4 pin as output */
  PORT4->IOCR0  &=  ~(0xFFUL << 0);          /* clear P4.0 settings           */
  PORT4->IOCR0  |=   (0x80UL << 0);          /* P4.0 output push pull         */
  PORT4->PDR0   &=  ~(0x07UL << 0);          /* clear P4.0 output settings    */
  PORT4->PDR0   |=   (0x02UL << 0);          /* P4.0 output strong            */

  PORT4->IOCR0  &=  ~(0xFFUL << 8);          /* clear P4.1 settings           */
  PORT4->IOCR0  |=   (0x80UL << 8);          /* P4.1 output push pull         */
  PORT4->PDR0   &=  ~(0x07UL << 4);          /* clear P4.1 output settings    */
  PORT4->PDR0   |=   (0x02UL << 4);          /* P4.1 output strong            */

  LED_Off ();                               /* switch LEDs off               */

}


/*----------------------------------------------------------------------------
  Function that turns on requested LED
 *----------------------------------------------------------------------------*/
void LED_On () {

    PORT4->OMR = led_mask[0] ;  //P4.0
    PORT4->OMR = led_mask[1] ;  //P4.1

}

/*----------------------------------------------------------------------------
  Function that turns off requested LED
 *----------------------------------------------------------------------------*/
void LED_Off () {

    PORT4->OMR = (led_mask[0] << 16);  //P4.0
    PORT4->OMR = (led_mask[1] << 16);  //P4.1


}


