/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2014  SEGGER Microcontroller GmbH & Co. KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V5.24 - Graphical user interface for embedded applications **
All  Intellectual Property rights  in the Software belongs to  SEGGER.
emWin is protected by  international copyright laws.  Knowledge of the
source code may not be used to write a similar product.  This file may
only be used in accordance with the following terms:

The software has been licensed to  ARM LIMITED whose registered office
is situated at  110 Fulbourn Road,  Cambridge CB1 9NJ,  England solely
for  the  purposes  of  creating  libraries  for  ARM7, ARM9, Cortex-M
series,  and   Cortex-R4   processor-based  devices,  sublicensed  and
distributed as part of the  MDK-ARM  Professional  under the terms and
conditions  of  the   End  User  License  supplied  with  the  MDK-ARM
Professional. 
Full source code is available at: www.segger.com

We appreciate your understanding and fairness.
----------------------------------------------------------------------
File        : LCD_X.c
Purpose     : Port routines for XMC4500 RGB with SPI
----------------------------------------------------------------------
*/
#include "GUI.h"
#include "RTE_Device.h"

/*********************************************************************
*
*       Hardware configuration
*
**********************************************************************
*/
#include "xmc_gpio.h"
#include "Driver_SPI.h"

#if (defined(RTE_SPI1) && (RTE_SPI1 == 0))
#error "Required SPI1 not configured in RTE_Device.h!"
#endif
#if (RTE_SPI1_TX_ID != 2)
#error "SPI1 TX MOSI pin selection not correct. Please use P3_13"
#endif
#if (RTE_SPI1_CLK_OUTPUT_ID != 1)
#error "SPI1 CLK OUTPUT pin selection not correct. Please use P3_0"
#endif
#if (RTE_SPI1_SLAVE_SELECT_LINE1 != 1)
#error "SPI1 SLAVE SELECT LINE 1 must be enabled"
#endif
#if (RTE_SPI1_SLAVE_SELECT_LINE_1_ID != 0)
#error "SPI1_SLAVE SELECT LINE 1 pin selection not correct. Please use P3_12"
#endif

#define OLED_CMD P5_11

/* SPI Interface: RTE_SPI3 (configured in RTE_Device.h)
     Pins:
       CS   = 31
       SCL  = 36
       MISO = 34
       MOSI = 32
*/

/* SPI Driver */
extern ARM_DRIVER_SPI   Driver_SPI1;
#define SPIdrv        (&Driver_SPI1)

/*********************************************************************
*
*       Exported code
*
*********************************************************************
*/
/*********************************************************************
*
*       LCD_X_Init
*
* Purpose:
*   This routine should be called from your application program
*   to set port pins to their initial values
*/
void LCD_X_Init(void) {
  
  /* Initialize CMD pin */
  XMC_GPIO_SetMode(OLED_CMD, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
  
  /* Initialize and configure SPI */
  SPIdrv->Initialize  (NULL);
  SPIdrv->PowerControl(ARM_POWER_FULL);
  SPIdrv->Control     (ARM_SPI_MODE_MASTER  |
                       ARM_SPI_CPOL1_CPHA0  |
                       ARM_SPI_MSB_LSB      |
                       ARM_SPI_SS_MASTER_SW |
                       ARM_SPI_DATA_BITS(8),
                       16666666);
	
	/* SS line = INACTIVE = HIGH */    
	SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_INACTIVE);
}

/*******************************************************************************
 * Write command
 *******************************************************************************/
void LCD_X_Write0_8(U8 c)
{
  XMC_GPIO_SetOutputLow(OLED_CMD);

  /* SS line = ACTIVE = LOW */
  SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_ACTIVE);

  SPIdrv->Send(&c, 1);
  while(SPIdrv->GetStatus().busy);
	
  /* SS line = INACTIVE = HIGH */
  SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_INACTIVE);
}

/*******************************************************************************
 * Write data
 *******************************************************************************/
void LCD_X_Write1_8(U8 c)
{
  XMC_GPIO_SetOutputHigh(OLED_CMD);

  /* SS line = ACTIVE = LOW */
  SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_ACTIVE);

  SPIdrv->Send(&c, 1);
  while(SPIdrv->GetStatus().busy);

  /* SS line = INACTIVE = HIGH */
  SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_INACTIVE);
}

/*******************************************************************************
 * Write multiple data
 *******************************************************************************/
void LCD_X_WriteM1_8(U8 * pData, int NumItems)
{
  XMC_GPIO_SetOutputHigh(OLED_CMD);

  /* SS line = ACTIVE = LOW */
  SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_ACTIVE);

  SPIdrv->Send(pData, NumItems);
  while(SPIdrv->GetStatus().busy);

  /* SS line = INACTIVE = HIGH */
  SPIdrv->Control(ARM_SPI_CONTROL_SS, ARM_SPI_SS_INACTIVE);
}

