/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/**
 * @file
 * @date 02 May, 2016
 * @version 1.0.0
 *
 * @brief XMC4500 App Kit RTX Blinky example
 *
 * Two threads are defined:
 * - one blinking a LED1
 * - another sampling the BUTTON1 and stopping the LED1 blinking if the BUTTON1 is pressed
 *
 * History
 *
 * Version 1.0.0 
 * - Initial
 *
 */

#include "RTE_Components.h"
#include CMSIS_device_header

#include "BOARD_Led.h"

#include "FreeRTOS.h"
#include "task.h"

#include "lwip/tcpip.h"
#include "ethernetif.h"

/* Static IP ADDRESS */
#define IP_ADDR0   192
#define IP_ADDR1   168
#define IP_ADDR2   0
#define IP_ADDR3   11

/* NETMASK */
#define NETMASK_ADDR0   255
#define NETMASK_ADDR1   255
#define NETMASK_ADDR2   255
#define NETMASK_ADDR3   0

/* Gateway Address */
#define GW_ADDR0   192
#define GW_ADDR1   168
#define GW_ADDR2   0
#define GW_ADDR3   1

static struct netif netif_0;

void vApplicationIdleHook( void )
{
  ethernetif_check_link(&netif_0);
  ethernetif_poll(&netif_0);
}

void netif_link_callback(struct netif *const netif)
{
  if (netif_is_link_up(netif))
  {
    netif_set_up(netif);
  }
  else
  {
    netif_set_down(netif);
  }
}

static __NO_RETURN void led1_task(void *arg)
{ 
  (void)arg;

  while (1)
  {
    LED_On(0);
    vTaskDelay(pdMS_TO_TICKS(1000));
    LED_Off(0);
    vTaskDelay(pdMS_TO_TICKS(1000));
  }
}

__NO_RETURN int main(void)
{
	LED_Initialize();
	
  /* Initialize TCP/IP stack */
  tcpip_init( NULL, NULL );

  if (netif_add_noaddr(&netif_0, NULL, ethernetif_init, tcpip_input) == NULL)
  {
    // error
    while(1);
  }

#if LWIP_DHCP == 0
  ip_addr_t ipaddr;
  ip_addr_t netmask;
  ip_addr_t gw;

  IP4_ADDR(&ipaddr, IP_ADDR0, IP_ADDR1, IP_ADDR2, IP_ADDR3);
  IP4_ADDR(&netmask, NETMASK_ADDR0, NETMASK_ADDR1 , NETMASK_ADDR2, NETMASK_ADDR3);
  IP4_ADDR(&gw, GW_ADDR0, GW_ADDR1, GW_ADDR2, GW_ADDR3);

  netif_set_addr(&netif_0, &ipaddr, &netmask, &gw);
#endif

  netif_set_link_callback(&netif_0, netif_link_callback);

  /* Create tasks. */
  xTaskCreate(led1_task, "led1_task", configMINIMAL_STACK_SIZE, NULL, tskIDLE_PRIORITY, NULL);

  /* Start the tasks running. */
  vTaskStartScheduler();
	
  while(1);	
}
