/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/*------------------------------------------------------------------------------
 * Name:    Main.c
 * Purpose: I2C Driver Example
 *----------------------------------------------------------------------------*/
#include "RTE_Components.h"
#include  CMSIS_device_header

#include "Driver_I2C.h"

 /* IO expander address on COM board */
#define COM_PCA9502_ADDRESS (0x98)

/* IO expander address on HMI board */
#define  HMI_PCA9502_ADDRESS (0x9A)

#define IO_EXPANDER_ADDRESS HMI_PCA9502_ADDRESS


uint8_t dir[2]={0x50,0xff};
/* USART Driver */
extern ARM_DRIVER_I2C Driver_I2C2;

uint8_t *data; 
 
typedef enum PCA9502_REGADDR {
    IO_DIR    = 0xA << 3,
    IO_STATE  = 0xB << 3,
    IO_INTE   = 0xC << 3,
    IO_CTRL   = 0xE << 3
} PCA9502_REGADDR_t;



void myI2C_callback(uint32_t event)
{
    switch (event)
    {
    case ARM_I2C_EVENT_TRANSFER_DONE:    
    case ARM_I2C_EVENT_TRANSFER_INCOMPLETE:
    case ARM_I2C_EVENT_SLAVE_TRANSMIT:
    case ARM_I2C_EVENT_SLAVE_RECEIVE:
       
        break;
    }
}

void delay(uint32_t counter)
{
	while(--counter)
	{
		__NOP();
	}
} 

int main(void)
{
  static ARM_DRIVER_I2C * I2Cdrv = &Driver_I2C2;
	uint8_t received_data1=0;
	uint8_t data0[]={IO_DIR,0xff};
	uint8_t data1[]={IO_STATE,0xBB};
	uint8_t data2[]={IO_STATE,0x44};
	
	/*Initialize the I2C driver */
	I2Cdrv->Initialize(myI2C_callback);
	/*Power up the I2C	peripheral */
	I2Cdrv->PowerControl(ARM_POWER_FULL);
	
	/*Configure the I2C	peripheral */
	I2Cdrv->Control(ARM_I2C_BUS_SPEED,ARM_I2C_BUS_SPEED_STANDARD);
	
	/*Transmit the address and reset the LEDs */
	I2Cdrv->MasterTransmit(IO_EXPANDER_ADDRESS,data0,2,false);
	while (I2Cdrv->GetStatus().busy){};
			
	/*Send commands to handle the LEDs */	
	I2Cdrv->MasterTransmit(IO_EXPANDER_ADDRESS,data1,2,false);
	while (I2Cdrv->GetStatus().busy){};
		
	/* Delay to make visible the change */
	delay(0x1ffffff);
		
	I2Cdrv->MasterTransmit(IO_EXPANDER_ADDRESS,data2,2,false);
	while (I2Cdrv->GetStatus().busy){};
		
	 /* Delay to make visible the change */
	delay(0x1ffffff);
		
	I2Cdrv->MasterTransmit(IO_EXPANDER_ADDRESS,data1,2,false);
	while (I2Cdrv->GetStatus().busy){};
		
	/* Delay to make visible the change */
	delay(0x1ffffff);
		
	I2Cdrv->MasterTransmit(IO_EXPANDER_ADDRESS,data2,2,false);
	while (I2Cdrv->GetStatus().busy){};
		
	I2Cdrv->MasterTransmit(IO_EXPANDER_ADDRESS,data2,1,true);
	while (I2Cdrv->GetStatus().busy){};

	/* Read back the data */
	I2Cdrv->MasterReceive(IO_EXPANDER_ADDRESS,&received_data1,1,false);
	while (I2Cdrv->GetStatus().busy){};
		
	/* Check if the data is correct */	
  if(data2[1] != received_data1)
  {
    while(1);
  }	
	while (1)
	{ 
	}
 
}
