/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

#include "RTE_Components.h"
#include  CMSIS_device_header

#include "Driver_I2C.h"
#include "Driver_SAI.h"

#include "xmc_gpio.h"

#define AIC3204_ADDR    0x30

static unsigned long timingdelay;
extern uint16_t Test_Buffer[246948];
extern ARM_DRIVER_I2C Driver_I2C2;
extern ARM_DRIVER_SAI Driver_SAI1;

static ARM_DRIVER_I2C *I2Cdrv = &Driver_I2C2;
static ARM_DRIVER_SAI *SAIdrv = &Driver_SAI1;

uint8_t AIC3204_commands[] = {0x00, 0x00,     /* Select Page 0 */
	                            0x01, 0x01,     /* Initialize the device through software reset */
															0x00, 0x00,     /* Select Page 0 */
                              0x04, 0x07,     /* Select MCLK as PLL_clkin; Select PLL_CLK as CODEC_CLKIN */
	                            0x05, 0x93,     /* Set PLL on, P=1, R=3 */
	                            0x06, 0x08,     /* Set J=8 */
	                            0x07, 0x00,     /* Set PLLD=0 */
	                            0x08, 0x00,     
	                            0x0B, 0x85,     /* NDAC = 5, dividers powered on */
	                            0x0C, 0x83,     /* MDAC = 3, dividers powered on */
													    0x0D, 0x00,     /* Program the OSR of DAC to 128 */
	                            0x0E, 0x80,
	                            0x12, 0x85,     /* NADC = 5, dividers powered on */
	                            0x13, 0x83,     /* MADC = 3, dividers powered on */
	                            0x14, 0x80,     /* Program the OSR of ADC to 128 */
	                            0x1B, 0x00,     /* Audio Interface = I2S; Data Word length = 16 bits; BCLK is input to the device */   
	                            0x3C, 0x01,     /* DAC Signal Processing Block PRB_P1 */
	                            0x00, 0x2C,     /* Point to Page 44 */
	                            0x01, 0x04,     /* Adaptive Filtering enabled for DAC */
	                            0x00, 0x01,     /* Select Page 1 */
	                            0x01, 0x08,     /* Disable weak AVDD in presence of external; AVDD supply */
	                            0x02, 0x01,     /* Enable Master Analog Power Control */
	                            0x47, 0x32,     /* Set the input power-up time to 3.1ms (for ADC) */
	                            0x7B, 0x01,     /* Set the REF charging time to 40ms */
													    0x00, 0x01,     /* Select Page 1 */
													    0x03, 0x00,     /* Set the DAC PTM mode to PTM_P3 */
													    0x04, 0x00,     /* Set the DAC PTM mode to PTM_P4 */
													    0x14, 0x25,     /* De-pop: 5 time constants, 6k resistance */
													    0x0A, 0x00,     /* Set the Input Common Mode to 0.9V and Output Common Mode for Headphone to Input Common Mode */
													    0x0C, 0x08,     /* Route Left DAC to HPL */
										    	    0x0D, 0x08,     /* Route Right DAC to HPR */
										    	    0x0E, 0x08, 
										  		    0x0F, 0x08,
										  		    0x10, 0x80,     /* Unmute HPL driver, 0dB Gain */
										  		    0x11, 0x80,     /* Unmute HPR driver, 0dB Gain */
										  		    0x09, 0x3C,     /* Power up HPL/HPR */
										  		    0x00, 0x00,     /* Select Page 0 */
										  		    0x41, 0x30,     /* DAC => 0dB */
										  		    0x42, 0x30,     
										  		    0x3F, 0xD6,     /* Power up LDAC/RDAC */
										  		    0x40, 0x00};    /* Unmute the DAC digital volume control */

uint16_t AIC3204_delays[] = {0, 1000, 100, 100, 100, 100, 0, 0, 100, 100, 0, 100, 100, 100, 100, 100, 0, 0, 0, 100, 100, 1000, 1000, 1000, 100, 0, 0, 100, 100, 100, 100, 0, 100, 0, 100, 25100, 100, 0, 0, 100, 100};
							 
void myI2C_callback(uint32_t event)
{
}

void mySAI_callback(uint32_t event)
{
}

void myMCI_callback(uint32_t event)
{
}

//**++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//  Description	Decrements the variable timingdelay
//  This routine will be call by SysTick Exception (Excepetion 15)
//**++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
void TimingDelay_Decrement(void)
{
  if (timingdelay != 0x00)
  {
    timingdelay--;
  }
}

void SysTick_Handler(void)
{
 TimingDelay_Decrement();
}

void DelayInit()
{
  SysTick_Config(12000);	// 0.1 ms = 100us
}

//**++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//  Description	Inserts a delay time.
//  Parameter  	nTime: specifies the delay time length, in 100 micro seconds.
//**++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
void Delay100US(unsigned long time)
{
  timingdelay = time;
  while(timingdelay != 0);
}


int main(void)
{
	uint8_t comm_index, delay_index;
	
	XMC_GPIO_SetMode(P2_10, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);
	
	I2Cdrv->Initialize(myI2C_callback);
	SAIdrv->Initialize(mySAI_callback);
	
	I2Cdrv->PowerControl(ARM_POWER_FULL);
	
	I2Cdrv->Control(ARM_I2C_BUS_SPEED,ARM_I2C_BUS_SPEED_STANDARD);
	
	DelayInit();
	
	XMC_GPIO_SetOutputLow(P2_10);
	Delay100US(10);
  XMC_GPIO_SetOutputHigh(P2_10);
  Delay100US(20);
		
	for(comm_index = 0, delay_index = 0; comm_index < sizeof(AIC3204_commands); comm_index+=2, delay_index++){
    I2Cdrv->MasterTransmit(AIC3204_ADDR, &AIC3204_commands[comm_index], 2, false);
	  while (I2Cdrv->GetStatus().busy){};
			if (AIC3204_delays[delay_index]){
		    Delay100US(AIC3204_delays[delay_index]);
			}
	}
	
	SAIdrv->PowerControl(ARM_POWER_FULL);
	
  SAIdrv->Control(ARM_SAI_CONFIGURE_TX | ARM_SAI_MODE_MASTER  | ARM_SAI_ASYNCHRONOUS | ARM_SAI_PROTOCOL_I2S | ARM_SAI_DATA_SIZE(16), 0, 44100);
	
  SAIdrv->Control(ARM_SAI_CONTROL_TX, 1, 0);

	SAIdrv->Send(&Test_Buffer, 246948);
		
	while(1);
}

