/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

#include <stdio.h>

#include "RTE_Components.h"
#include  CMSIS_device_header

#include "cmsis_os.h"                   /* CMSIS RTOS definitions             */
#include "rl_net.h"                     /* Network definitions                */
#include "rl_fs.h"                      /* File System definitions            */

#include "Board_LED.h"

static void BlinkLed (void const *arg);

osThreadDef(BlinkLed, osPriorityNormal, 1, 0);

/*----------------------------------------------------------------------------
  Thread 'BlinkLed': Blink the LED on an eval board
 *---------------------------------------------------------------------------*/
__NO_RETURN static void BlinkLed (void const *arg) {
  while(1) 
	{
    LED_On(0);
    osDelay(200);
		LED_Off(0);
    osDelay(200);
  }
}

static void init_filesystem(void) 
{
  fsStatus stat;
	
	if (finit("M0:") == fsOK) 
	{
    if (fmount("M0:") == fsOK)
		{
      printf ("Drive M0 ready!\n");
    }
    else {
      printf ("Drive M0 mount failed with error code %d\n", stat);
			while(1);
    }
  }
  else 
	{
    printf ("Drive M0 initialization failed!\n");
		while(1);
  }	
}

// Process DCHP server information
void netDHCP_Notify (uint32_t if_num, uint8_t option, const uint8_t *val, uint32_t len) {
  char ip_ascii[16];
  
  switch (option)  {
    case NET_DHCP_OPTION_IP_ADDRESS:           // IP address has changed
      netIP_ntoa (NET_ADDR_IP4, &val[0], ip_ascii, sizeof(ip_ascii));
      printf ("IP address: %s\n", ip_ascii);
      break;
		
		default:
			break;
  
  }   
}

/*----------------------------------------------------------------------------
  Main Thread 'main': Run Network
 *---------------------------------------------------------------------------*/
__NO_RETURN int main (void) 
{
  LED_Initialize();
  
  init_filesystem();	

  osThreadCreate (osThread(BlinkLed), NULL);

  netInitialize();

  while (1)
	{
		osThreadYield();
	}
}
