/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::USB:Host:MSC
 * Copyright (c) 2004-2015 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    USBD_MSC_0.h
 * Purpose: Functions for media ownership control between USB and File System
 * Rev.:    V6.3
 *----------------------------------------------------------------------------*/

#ifndef USBD_MSC0_H
#define USBD_MSC0_H

#include "stdint.h"                     // data type definitions

#define USBD_MSC0_MEDIA_OWN_USB  (1U   ) ///< Media owned by USB (bit mask)
#define USBD_MSC0_MEDIA_OWN_CHG  (1U<<1) ///< Media ownership change requested (bit mask)

#define USBD_MSC0_OK               0     ///< Function succeeded
#define USBD_MSC0_ERROR           -1     ///< Unspecified error


/// \brief Set USB as media owner
/// \return     execution status
///               - USBD_MSC0_OK           = Media ownership changed successfully
///               - USBD_MSC0_ERROR        = Media ownership change has failed (due timeout)
extern int32_t USBD_MSC0_SetMediaOwnerUSB (void);


/// \brief Set File System as media owner
/// \return     execution status
///               - USBD_MSC0_OK           = Media ownership changed successfully
///               - USBD_MSC0_ERROR        = Media ownership change has failed (due timeout)
extern int32_t USBD_MSC0_SetMediaOwnerFS (void);

#endif
