/*-----------------------------------------------------------------------------
 * Name:    Keyboard.c
 * Purpose: Low level Keyboard functions
 *-----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2004-2013 KEIL - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "Keyboard.h"
#include "XMC4500.h"                    // Device header

#define NUM_KEYS        2               /* Number of available keys           */

/* Keys for Relax Kit */
#define BUTTON1_MASK       (1 << 0)
#define BUTTONx_PORT        PORT1
#define BUTTON1_BIT        (1 << 14)
#define BUTTON2_MASK       (1 << 1)
#define BUTTON2_BIT        (1 << 15)


/*-----------------------------------------------------------------------------
 *      Keyboard_Initialize:  Initialize keyboard/buttons
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
void Keyboard_Initialize (void) {

  /* configure PORT P1.14..15 pin as input */
  PORT1->IOCR12  &= ~((0xFFUL <<  16) |       /* clear P1.14 settings - this sets Port to input */
                      (0xFFUL <<  24)  );     /* clear P1.15 settings - this sets Port to input */
}


/*-----------------------------------------------------------------------------
 *      Keyboard_Uninitialize:  Uninitialize keyboard/buttons
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
void Keyboard_Uninitialize (void) {
}


/*-----------------------------------------------------------------------------
 *      Keyboard_GetKeys:  Get keyboard state
 *
 * Parameters: (none)
 * Return:      Keys bitmask
 *----------------------------------------------------------------------------*/
uint32_t Keyboard_GetKeys (void) {
  /* Read board keyboard inputs */
  uint32_t val = 0;
	
  if ((BUTTONx_PORT->IN & (BUTTON1_BIT)) == 0) {
    /* User button */
    val |= BUTTON1_MASK;
  }
  if ((BUTTONx_PORT->IN & (BUTTON2_BIT)) == 0) {
    /* User button */
    val |= BUTTON2_MASK;
  }
  return (val);
}


/*-----------------------------------------------------------------------------
 *      Keyboard_NumKeys:  Get number of available keys
 *
 * Parameters: (none)
 * Return:      number of keys
 *----------------------------------------------------------------------------*/
uint32_t Keyboard_NumKeys (void) {
  return (NUM_KEYS);
}
