/*------------------------------------------------------------------------------
 * Name:    main.c
 * Purpose: USB Device Human Interface Device example program
 *----------------------------------------------------------------------------*/
 
#include "cmsis_os2.h"
#include "rl_usb.h"

#include "BOARD_Led.h"
#include "BOARD_Buttons.h"

#define APP_MAIN_STK_SZ (1024U)
uint64_t app_main_stk[APP_MAIN_STK_SZ / 8];
const osThreadAttr_t app_main_attr = {
  .stack_mem  = &app_main_stk[0],
  .stack_size = sizeof(app_main_stk)
};

__NO_RETURN void app_main(void *arg) 
{
  uint32_t buttons_state_last = 0;
		
  LED_Initialize();
  Buttons_Initialize();
	
  USBD_Initialize    (0);               /* USB Device 0 Initialization        */
  USBD_Connect       (0);               /* USB Device 0 Connect               */

	uint32_t buttons_mask = (1 << Buttons_GetCount()) - 1;
  while (1) {                           /* Loop forever                       */
    uint32_t buttons_state = (uint8_t)(Buttons_GetState());
		if (((buttons_state ^ buttons_state_last) & buttons_mask) != 0)
		{
			buttons_state_last = buttons_state;
      if (USBD_Configured(0)){
				USBD_HID_GetReportTrigger(0, 0, (uint8_t *)&buttons_state, 1);
			}
    }
    osDelay(100);                       /* 100 ms delay for sampling buttons  */
  }
}

__NO_RETURN int main(void)
{
  /* Initialize CMSIS-RTOS2 */
 if(osKernelGetState() == osKernelInactive) {
    osKernelInitialize();
  }
  /* Create application main thread */
  osThreadNew(app_main, NULL, &app_main_attr);

  /* Start thread execution */
  if (osKernelGetState() == osKernelReady) {        // If kernel is ready to run...
    osKernelStart();                                // ... start thread execution
    }
	
  /* Infinite loop */
  while (1)
  {
  }
}
