/*-----------------------------------------------------------------------------
 * Name:    Buttons_XMC4500.c
 * Purpose: Buttons interface for Infineon XMC4500 Relax Kit
 * Rev.:    1.00
 *----------------------------------------------------------------------------*/

 /* Copyright (c) 2013 - 2015 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

#include "xmc_gpio.h" 
#include "Board_Buttons.h"

/* Buttons for XMC4500 */
#define BUTTONS_COUNT             (2)
#define BUTTONS_1_MASK            (1<<0)
#define BUTTONS_1_PORT_PIN        P1_14
#define BUTTONS_2_MASK            (1<<1)
#define BUTTONS_2_PORT_PIN        P1_15

// Buttons initialization
XMC_GPIO_CONFIG_t buttons_config;

/**
  \fn          int32_t Buttons_Initialize (void)
  \brief       Initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Initialize (void) {
  /* configure PORT P1.14..15 pin as inverted input, no internal pull device  */
	buttons_config.mode = XMC_GPIO_MODE_INPUT_TRISTATE;
	XMC_GPIO_Init(BUTTONS_1_PORT_PIN, &buttons_config);
	XMC_GPIO_Init(BUTTONS_2_PORT_PIN, &buttons_config);
  return 0;
}

/**
  \fn          int32_t Buttons_Uninitialize (void)
  \brief       De-initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t Buttons_Uninitialize (void) {
	/* configure PORT P1.14..15 pin with default values  */
	buttons_config.mode = (XMC_GPIO_MODE_t) 0;
	buttons_config.output_level = (XMC_GPIO_OUTPUT_LEVEL_t) 0;
	buttons_config.output_strength = (XMC_GPIO_OUTPUT_STRENGTH_t) 0;
	XMC_GPIO_Init(BUTTONS_1_PORT_PIN, &buttons_config);
	XMC_GPIO_Init(BUTTONS_2_PORT_PIN, &buttons_config);
  return 0;
}

/**
  \fn          uint32_t Buttons_GetState (void)
  \brief       Get buttons state
  \returns     Buttons state
*/
uint32_t Buttons_GetState (void) {
  uint32_t val = 0;
  if (XMC_GPIO_GetInput(BUTTONS_1_PORT_PIN) == 0) {
    val |= BUTTONS_1_MASK;
  }
  if (XMC_GPIO_GetInput(BUTTONS_2_PORT_PIN) == 0) {
    val |= BUTTONS_2_MASK;
  }
  return val;
}

/**
  \fn          uint32_t Buttons_GetCount (void)
  \brief       Get number of available buttons
  \return      Number of available buttons
*/
uint32_t Buttons_GetCount (void) {
  return BUTTONS_COUNT;
}
