/*
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *
 */

/**
 * @file
 * @date 02 May, 2016
 * @version 1.0.0
 *
 * @brief XMC1100 XMC_2Go RTX Blinky example
 *
 * Two threads are defined to switch on/off the LEDs in the board periodically
 *
 * History
 *
 * Version 1.0.0 
 * - Initial
 *
 */

#include "Board_LED.h"
#include "cmsis_os.h"

/*----------------------------------------------------------------------------
 * blinkLED: blink LED and wait for signal to go to next LED
 *----------------------------------------------------------------------------*/
void blinkLED(void const *argument) 
{
  for (;;) 
	{
		LED_On(0);
    osSignalWait(0x0001, osWaitForever);
		LED_On(1);
    osSignalWait(0x0001, osWaitForever);
		LED_Off(0);
    osSignalWait(0x0001, osWaitForever);
		LED_Off(1);
    osSignalWait(0x0001, osWaitForever);
  }

}
osThreadDef(blinkLED, osPriorityNormal, 1, 0);


__NO_RETURN int main(void)
{
	/* Initialize peripherals */
	LED_Initialize();
	
  /* create threads */
  osThreadId tid_blinkLED = osThreadCreate(osThread(blinkLED), NULL);

  for (;;) 
	{
    osDelay(500);
    osSignalSet(tid_blinkLED, 0x0001);
  }
}
