/*****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *****************************************************************************
 * @file
 * @date 05 Dec, 2014
 * @version 1.0.0
 *
 * @brief XMC1200Bot kit RTC demo example
 *
 * The RTC demo example programs the alarm to 1 minute after the start of the application
 * The triggered interrupt will switch off the LED connected to P0.6 of the bootkit
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 *
 */


#include "xmc_rtc.h"
#include "xmc_gpio.h"
#include "xmc_scu.h"

#define TICKS_PER_SECOND 1000
#define TICKS_WAIT 500

#define LED P0_6

XMC_RTC_CONFIG_t rtc_config =
{
  .alarm.minutes = 1U,
  .prescaler = 0x7fffU
};

void SCU_1_IRQHandler(void)
{
  XMC_GPIO_ToggleOutput(LED);
}

int main(void)
{
  XMC_GPIO_SetMode(LED, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);

  XMC_RTC_Init(&rtc_config);

  XMC_RTC_EnableEvent(XMC_RTC_EVENT_ALARM);
  XMC_SCU_INTERRUPT_EnableEvent(XMC_SCU_INTERRUPT_EVENT_RTC_ALARM);
  NVIC_SetPriority(SCU_1_IRQn, 3);
  NVIC_EnableIRQ(SCU_1_IRQn);

  XMC_RTC_Start();

  while (1)
  {
    /* Infinite loop */
  }
}
