/*****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *****************************************************************************
 * @file
 * @date 20 May, 2015
 * @version 1.0.2
 *
 * @brief ACMP example for XMC1300
 *
 * In this example, ACMP1 slice is configured to receive VRef/2 on its IN-P pad.
 * Connect VDD to pin P2.11.
 * Bit field CMP_OUT of register ANACMP1 changes its state based on the input applied on IN-N pad.
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 * Version 1.0.2 a. Updated for changes in the ACMP LLD (Version 2.0.0).
 *               b. Explicit call to enable comparator is added<br>
 *               c. Corrected g_acmp_config structure hysteresis element mistake<br>
 *
 */

/*********************************************************************************************************************
 * HEADER FILES
 ********************************************************************************************************************/
#include "xmc_acmp.h"

/*********************************************************************************************************************
 * GLOBAL DATA
 ********************************************************************************************************************/

/* ACMP Slice configuration */
XMC_ACMP_CONFIG_t g_acmp_config =
{
  .filter_disable = 0U,
  .output_invert = 0U,
  .hysteresis = XMC_ACMP_HYSTERESIS_20
};

/*********************************************************************************************************************
 * MAIN APPLICATION
 ********************************************************************************************************************/

int main(void)
{
  XMC_ACMP_Init(XMC_ACMP0, 1, &g_acmp_config);

  /* Connect REF to IN-P */
  XMC_ACMP_EnableReferenceDivider();

  XMC_ACMP_EnableComparator(XMC_ACMP0, 1);

  /* Users may now apply inputs on P2.6 and evaluate the state of ANACMP1:CMP_OUT bit*/
  while (1U)
  {
    /* Infinite loop */
  }
}
