/*****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library 
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.                        
 *                                             
 * Boost Software License - Version 1.0 - August 17th, 2003
 * 
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 * 
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *                                                                              
 * To improve the quality of the software, users are encouraged to share 
 * modifications, enhancements or bug fixes with Infineon Technologies AG 
 * at XMCSupport@infineon.com.
 *****************************************************************************
 * @file
 * @date 07 Aug, 2017
 * @version 1.0.0
 *
 * @brief XMC1300 Boot MATH coprocessor SQRT example
 *
 * The example demonstrates the usage of the CORDIC coprocessor to calculate the square root of a number
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 *
 */


#include <math.h>

#include "xmc_common.h"
#include "xmc_math.h"

__STATIC_INLINE void InitSysTickCounter(void)
{
  SysTick->VAL   = 0UL;                                             /* Load the SysTick Counter Value */
  SysTick->LOAD  = SysTick_LOAD_RELOAD_Msk;
  SysTick->CTRL  = SysTick_CTRL_CLKSOURCE_Msk;
}

__STATIC_INLINE void ResetSysTickCounter(void)
{
  SysTick->VAL   = 0UL;                                             /* Load the SysTick Counter Value */
}

__STATIC_INLINE void StartSysTickCounter(void)
{
  SysTick->CTRL  |= SysTick_CTRL_ENABLE_Msk;
}

__STATIC_INLINE void StopSysTickCounter(void)
{
  SysTick->CTRL  &= (uint32_t)~SysTick_CTRL_ENABLE_Msk;
}

__STATIC_INLINE uint32_t GetSysTickCounter(void)
{
  return (SysTick->VAL);
}

__STATIC_INLINE float q15_to_float(int16_t a) { return (float)a / 0x8000; }
__STATIC_INLINE float q31_to_float(int32_t a) { return (float)a / 0x80000000; }
__STATIC_INLINE int32_t float_to_q15(float a) { return (int16_t)((a * 0x8000) + 0.5F); }
__STATIC_INLINE int32_t float_to_q31(float a) { return (int32_t)((a * 0x80000000) + 0.5F); }

uint32_t tdelta_cordic, tdelta_software;
float error;

int main(void)
{
  int32_t a;
  uint32_t t1, t2;
  float b, c;

  InitSysTickCounter();
  StartSysTickCounter();
  t1 = GetSysTickCounter();
  a = XMC_MATH_CORDIC_Q31_Sqrt(float_to_q31(0.1F));
  t2 = GetSysTickCounter();
  b = q31_to_float(a);
  tdelta_cordic = t1 - t2;

  StopSysTickCounter();
  ResetSysTickCounter();
  StartSysTickCounter();

  t1 = GetSysTickCounter();
  c = sqrtf(0.1F);
  t2 = GetSysTickCounter();
  tdelta_software = t1 - t2;
  
  error = b - c;

  /* avoid compiler warning */
  (void)error;

  /* Placeholder for user application code. The while loop below can be replaced with user application code. */
  while(1)
  {
  }
}
