/*****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library 
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.                        
 *                                             
 * Boost Software License - Version 1.0 - August 17th, 2003
 * 
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 * 
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *                                                                              
 * To improve the quality of the software, users are encouraged to share 
 * modifications, enhancements or bug fixes with Infineon Technologies AG 
 * at XMCSupport@infineon.com.
 *****************************************************************************
 * @file
 * @date 01 Aug, 2014
 * @version 0.1.0
 *
 * @brief XMC1000 Bootkit Watchdog demo example
 *
 * Watchdog example in which the watchdog needs to be feed every second
 * The example feeds the watchdog 25 times (see blinking LED), after that the device goes into reset
 * since no more feeding occurs simulating a fault (see LED stays on).
 *
 * History <br>
 *
 * Version 0.1.0 Initial <br>
 *
 */

#include <xmc_wdt.h>
#include <xmc_scu.h>
#include <xmc_gpio.h>

#define TICKS_PER_SECOND 1000
#define TICKS_WAIT 1000
#define MAX_NUM_FEEDS 25

#define LED P0_6

XMC_WDT_CONFIG_t wdt_config =
{
  .window_lower_bound = 30000,
  .window_upper_bound = 35000,
  .service_pulse_width = 255
};

void SysTick_Handler(void)
{
  static uint32_t ticks = 0;
  static uint32_t feeds = 0;

  ticks++;
  if (ticks == TICKS_WAIT && feeds < MAX_NUM_FEEDS)
  {
    XMC_GPIO_ToggleOutput(LED);
    XMC_WDT_Service();
    ticks = 0;
    feeds++;
  }
}


int main(void)
{
  XMC_GPIO_SetMode(LED, XMC_GPIO_MODE_OUTPUT_PUSH_PULL);

  if ((XMC_SCU_RESET_GetDeviceResetReason() & XMC_SCU_RESET_REASON_WATCHDOG) != 0)
  {
    XMC_GPIO_SetOutputHigh(LED);

	  while(1)
	  {
	    /* Infinite loop */
	  }
  }

  /* Clear system reset status */
  /* Note: API will be added in the next release */
  SCU_RESET->RSTCLR |= SCU_RESET_RSTCLR_RSCLR_Msk;

  XMC_WDT_Init(&wdt_config);

  XMC_WDT_Start();

  /* Feed the watchdog periodically every 1s */
  SysTick_Config(SystemCoreClock / TICKS_PER_SECOND);

  while(1)
  {
  	/* Infinite loop */
  }
}
