/**
 * @file retarget_io.c
 * @date 2021-01-08
 * @brief XMC1400 Bootkit TSE example
 *
 * @cond
 *****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *****************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-11-09:
 *     - Initial version
 *
 * 2021-01-08:
 *     - Fixed compilation for ARMClang
 * 
 * @endcond
 *
 */

#include <stdio.h>
#include "xmc_uart.h"

#if defined ( __GNUC__ ) && !defined (__ARMCC_VERSION)

/* Forward prototypes.  */
int _write(int fd, const void *buf, size_t count) __attribute__((externally_visible));
int _read(int fd, void *buf, size_t count) __attribute__((externally_visible));

int _write(int fd, const void *buf, size_t count)
{
  (void)fd;

  for (int i = 0; i < count; ++i)
  {
    XMC_UART_CH_Transmit(XMC_UART0_CH1, *(const uint8_t *)buf);
    buf++;
  }
  return count;
}

int _read(int fd, void *buf, size_t count)
{
  int char_cnt = 0;
  (void)fd;

  while ((XMC_UART_CH_GetStatusFlag(XMC_UART0_CH1) & (XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION |
                                                      XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION)) == 0);

  char_cnt++;
  *(uint8_t *)buf = XMC_UART_CH_GetReceivedData(XMC_UART0_CH1);

  XMC_UART_CH_ClearStatusFlag(XMC_UART0_CH1, XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION |
                                             XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION);

  return char_cnt;
}
#endif


#if defined(__CC_ARM) || defined(__ARMCC_VERSION)
int stdout_putchar(int ch, FILE *f)
{
  (void)f;
  XMC_UART_CH_Transmit(XMC_UART0_CH1, ch);
  return ch;
}

int stdin_getchar(FILE *f)
{
  (void)f;
  int result;
  
  while ((XMC_UART_CH_GetStatusFlag(XMC_UART0_CH1) & (XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION |
                                                      XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION)) == 0);

  result = XMC_UART_CH_GetReceivedData(XMC_UART0_CH1);

  XMC_UART_CH_ClearStatusFlag(XMC_UART0_CH1, XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION |
                                             XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION);

  return result;
}
#endif

#if defined(__ICCARM__)
size_t __write(int handle, const unsigned char *buffer, size_t size)
{
  (void)handle;

  for (int i = 0; i < size; ++i)
  {
    XMC_UART_CH_Transmit(XMC_UART0_CH1, *(const uint8_t *)buffer);
    buffer++;
  }
  return size;
}

int __read(int fd, void *buf, size_t count)
{
  int char_cnt = 0;
  (void)fd;

  while ((XMC_UART_CH_GetStatusFlag(XMC_UART0_CH1) & (XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION |
                                                      XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION)) == 0);

  char_cnt++;
  *(uint8_t *)buf = XMC_UART_CH_GetReceivedData(XMC_UART0_CH1);

  XMC_UART_CH_ClearStatusFlag(XMC_UART0_CH1, XMC_UART_CH_STATUS_FLAG_ALTERNATIVE_RECEIVE_INDICATION |
                                             XMC_UART_CH_STATUS_FLAG_RECEIVE_INDICATION);

  return char_cnt;
}
#endif

