/*****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *****************************************************************************
 * @file
 * @date 11 Sep, 2020
 * @version 1.0.0
 *
 * @brief XMC1400 Boot kit VADC conversion in background mode example
 *
 * The voltage at the potentiometer (P2.5) is converted in an endless loop
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 *
 */


/***************************************************************************
 * HEADER FILES
 **************************************************************************/
#include "xmc_vadc.h"

/***************************************************************************
 * CONFIGURATION
 **************************************************************************/
const XMC_VADC_GLOBAL_CONFIG_t g_global_handle =
{
	.wait_for_read_mode = true
};

/* Data configuration for background source. */
const XMC_VADC_BACKGROUND_CONFIG_t g_bgn_handle =
{
  .enable_auto_scan  = true
};


/* Channel data configuration. Channel does NOT use alias feature and uses
 * desired result register. */
const XMC_VADC_CHANNEL_CONFIG_t g_g1_ch7_handle =
{
    .alias_channel = XMC_VADC_CHANNEL_ALIAS_DISABLED,
    .use_global_result = true
};

/***************************************************************************
 * GLOBAL DATA
 **************************************************************************/
XMC_VADC_RESULT_SIZE_t result;

/***************************************************************************
 * FUNCTION IMPLEMENTATION
 **************************************************************************/
int main(void)
{
    /* Provide clock to VADC and initialize the VADC global registers. */
    XMC_VADC_GLOBAL_Init(VADC, &g_global_handle);

    /* Set VADC group to normal operation mode (VADC kernel). */
    XMC_VADC_GROUP_SetPowerMode(VADC_G1, XMC_VADC_GROUP_POWERMODE_NORMAL);

    /* Calibrate the VADC. Make sure you do this after all used VADC groups
     * are set to normal operation mode. */
    XMC_VADC_GLOBAL_StartupCalibration(VADC);

    /* Initialize the background source hardware. The gating mode is set to
     * ignore to pass external triggers unconditionally.*/
    XMC_VADC_GLOBAL_BackgroundInit(VADC, &g_bgn_handle);

    /* Initialize the channel unit. */
    XMC_VADC_GROUP_ChannelInit(VADC_G1, 7, &g_g1_ch7_handle);

    /* Add a channel to the background source. */
    XMC_VADC_GLOBAL_BackgroundAddChannelToSequence(VADC, 1, 7);

    /* Generate conversion request (load event). */
    XMC_VADC_GLOBAL_BackgroundTriggerConversion(VADC);

    while (1)
    {
        /* Retrieve result from result register. */
        while (XMC_VADC_GROUP_IsConverterBusy(VADC_G1) == XMC_VADC_GROUP_STATE_BUSY);
        result = XMC_VADC_GLOBAL_GetResult(VADC);
    }
}
