/**
 * @file xmc1_usic_map.h
 * @date 2019-07-30
 *
 * @cond
 *****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *****************************************************************************
 *
 * Change History
 * --------------
 *
 * 2015-02-20:
 *     - Initial version
 *
 * 2015-08-25:
 *     - Added XMC1400
 *
 * 2016-06-17:
 *     - Added support for XMC1201 TSSOP28, XMC1302 TSSOP28, XMC1402 TSSOP38, XMC1403 VQFN40
 *
 * 2016-08-22:
 *     - Added USIC1_C0_DX1_P3_4 for XMC14xx 64 pins package
 *
 * 2019-07-30:
 *     - Added support for XMC1404-Q040
 *
 * @endcond
 *
 */

#ifndef XMC1_USIC_MAP_H
#define XMC1_USIC_MAP_H

/**********************************************************************************************************************
 * MACROS
 *********************************************************************************************************************/

#define USIC_INPUT_ALWAYS_1     7

#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1200) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == TSSOP28)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == TSSOP28)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP28)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1401) && (UC_PACKAGE == LQFP64)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P3_3   	4
#define USIC1_C0_DX0_P3_4   	5
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P3_4   	4
#define USIC1_C0_DX1_P4_3   	1
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P3_1   	5
#define USIC1_C0_DX2_P4_10  	3
#define USIC1_C0_DX2_P4_11  	4
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX2_P4_8   	1
#define USIC1_C0_DX2_P4_9   	2
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P1_8   	1
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX3_P3_2   	2
#define USIC1_C0_DX3_P4_0   	3
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P1_8   	1
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_P3_2   	2
#define USIC1_C0_DX4_P4_0   	3
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P1_7   	1
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_P4_1   	2
#define USIC1_C0_DX5_P4_2   	3
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX0_P3_1   	5
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P1_8   	2
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_P1_7   	2
#define USIC1_C1_DX2_P3_3   	0
#define USIC1_C1_DX2_P3_4   	1
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX3_P3_2   	3
#define USIC1_C1_DX3_P4_11  	0
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_P3_2   	3
#define USIC1_C1_DX4_P4_11  	0
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_10  	0
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1401) && (UC_PACKAGE == VQFN48)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1402) && (UC_PACKAGE == LQFP64)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P3_3   	4
#define USIC1_C0_DX0_P3_4   	5
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P3_4   	4
#define USIC1_C0_DX1_P4_3   	1
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P3_1   	5
#define USIC1_C0_DX2_P4_10  	3
#define USIC1_C0_DX2_P4_11  	4
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX2_P4_8   	1
#define USIC1_C0_DX2_P4_9   	2
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P1_8   	1
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX3_P3_2   	2
#define USIC1_C0_DX3_P4_0   	3
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P1_8   	1
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_P3_2   	2
#define USIC1_C0_DX4_P4_0   	3
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P1_7   	1
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_P4_1   	2
#define USIC1_C0_DX5_P4_2   	3
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX0_P3_1   	5
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P1_8   	2
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_P1_7   	2
#define USIC1_C1_DX2_P3_3   	0
#define USIC1_C1_DX2_P3_4   	1
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX3_P3_2   	3
#define USIC1_C1_DX3_P4_11  	0
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_P3_2   	3
#define USIC1_C1_DX4_P4_11  	0
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_10  	0
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1402) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1402) && (UC_PACKAGE == VQFN48)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1402) && (UC_PACKAGE == VQFN64)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P3_3   	4
#define USIC1_C0_DX0_P3_4   	5
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P3_4   	4
#define USIC1_C0_DX1_P4_3   	1
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P3_1   	5
#define USIC1_C0_DX2_P4_10  	3
#define USIC1_C0_DX2_P4_11  	4
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX2_P4_8   	1
#define USIC1_C0_DX2_P4_9   	2
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P1_8   	1
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX3_P3_2   	2
#define USIC1_C0_DX3_P4_0   	3
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P1_8   	1
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_P3_2   	2
#define USIC1_C0_DX4_P4_0   	3
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P1_7   	1
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_P4_1   	2
#define USIC1_C0_DX5_P4_2   	3
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX0_P3_1   	5
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P1_8   	2
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_P1_7   	2
#define USIC1_C1_DX2_P3_3   	0
#define USIC1_C1_DX2_P3_4   	1
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX3_P3_2   	3
#define USIC1_C1_DX3_P4_11  	0
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_P3_2   	3
#define USIC1_C1_DX4_P4_11  	0
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_10  	0
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1402) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1403) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1403) && (UC_PACKAGE == VQFN48)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1403) && (UC_PACKAGE == VQFN64)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P3_3   	4
#define USIC1_C0_DX0_P3_4   	5
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P3_4   	4
#define USIC1_C0_DX1_P4_3   	1
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P3_1   	5
#define USIC1_C0_DX2_P4_10  	3
#define USIC1_C0_DX2_P4_11  	4
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX2_P4_8   	1
#define USIC1_C0_DX2_P4_9   	2
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P1_8   	1
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX3_P3_2   	2
#define USIC1_C0_DX3_P4_0   	3
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P1_8   	1
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_P3_2   	2
#define USIC1_C0_DX4_P4_0   	3
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P1_7   	1
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_P4_1   	2
#define USIC1_C0_DX5_P4_2   	3
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX0_P3_1   	5
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P1_8   	2
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_P1_7   	2
#define USIC1_C1_DX2_P3_3   	0
#define USIC1_C1_DX2_P3_4   	1
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX3_P3_2   	3
#define USIC1_C1_DX3_P4_11  	0
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_P3_2   	3
#define USIC1_C1_DX4_P4_11  	0
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_10  	0
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1404) && (UC_PACKAGE == LQFP64)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P3_3   	4
#define USIC1_C0_DX0_P3_4   	5
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P3_4   	4
#define USIC1_C0_DX1_P4_3   	1
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P3_1   	5
#define USIC1_C0_DX2_P4_10  	3
#define USIC1_C0_DX2_P4_11  	4
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX2_P4_8   	1
#define USIC1_C0_DX2_P4_9   	2
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P1_8   	1
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX3_P3_2   	2
#define USIC1_C0_DX3_P4_0   	3
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P1_8   	1
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_P3_2   	2
#define USIC1_C0_DX4_P4_0   	3
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P1_7   	1
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_P4_1   	2
#define USIC1_C0_DX5_P4_2   	3
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX0_P3_1   	5
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P1_8   	2
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_P1_7   	2
#define USIC1_C1_DX2_P3_3   	0
#define USIC1_C1_DX2_P3_4   	1
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX3_P3_2   	3
#define USIC1_C1_DX3_P4_11  	0
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_P3_2   	3
#define USIC1_C1_DX4_P4_11  	0
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_10  	0
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1404) && (UC_PACKAGE == VQFN48)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif


#if (UC_DEVICE == XMC1404) && (UC_PACKAGE == VQFN64)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX0_P3_3   	4
#define USIC1_C0_DX0_P3_4   	5
#define USIC1_C0_DX0_P4_4   	2
#define USIC1_C0_DX0_P4_5   	3
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX1_P3_4   	4
#define USIC1_C0_DX1_P4_3   	1
#define USIC1_C0_DX1_P4_5   	2
#define USIC1_C0_DX1_P4_6   	3
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX2_P3_1   	5
#define USIC1_C0_DX2_P4_10  	3
#define USIC1_C0_DX2_P4_11  	4
#define USIC1_C0_DX2_P4_7   	0
#define USIC1_C0_DX2_P4_8   	1
#define USIC1_C0_DX2_P4_9   	2
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P1_8   	1
#define USIC1_C0_DX3_P2_12  	0
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX3_P3_2   	2
#define USIC1_C0_DX3_P4_0   	3
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P1_8   	1
#define USIC1_C0_DX4_P2_12  	0
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_P3_2   	2
#define USIC1_C0_DX4_P4_0   	3
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P1_7   	1
#define USIC1_C0_DX5_P2_13  	0
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_P4_1   	2
#define USIC1_C0_DX5_P4_2   	3
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX0_P2_12  	2
#define USIC1_C1_DX0_P2_13  	3
#define USIC1_C1_DX0_P3_0   	4
#define USIC1_C1_DX0_P3_1   	5
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX1_P1_8   	2
#define USIC1_C1_DX1_P2_12  	1
#define USIC1_C1_DX1_P3_0   	3
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_P1_7   	2
#define USIC1_C1_DX2_P3_3   	0
#define USIC1_C1_DX2_P3_4   	1
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX3_P3_2   	3
#define USIC1_C1_DX3_P4_11  	0
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_P3_2   	3
#define USIC1_C1_DX4_P4_11  	0
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_P4_10  	0
#define USIC1_C1_DX5_P4_4   	5
#define USIC1_C1_DX5_SELO0  	6
#endif

#if (UC_DEVICE == XMC1404) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#define USIC1_C0_DX0_DX3INS 	6
#define USIC1_C0_DX0_P0_2   	0
#define USIC1_C0_DX0_P0_3   	1
#define USIC1_C0_DX1_DX0INS 	5
#define USIC1_C0_DX1_DX4INS 	6
#define USIC1_C0_DX1_P0_2   	0
#define USIC1_C0_DX2_DX5INS 	6
#define USIC1_C0_DX3_DOUT0  	6
#define USIC1_C0_DX3_DX5INS 	5
#define USIC1_C0_DX3_P2_3   	4
#define USIC1_C0_DX4_DX5INS 	5
#define USIC1_C0_DX4_P2_3   	4
#define USIC1_C0_DX4_SCLKOUT	6
#define USIC1_C0_DX5_P2_2   	4
#define USIC1_C0_DX5_P2_4   	5
#define USIC1_C0_DX5_SELO0  	6
#define USIC1_C1_DX0_DX3INS 	6
#define USIC1_C1_DX0_P0_0   	0
#define USIC1_C1_DX0_P0_1   	1
#define USIC1_C1_DX1_DX0INS 	5
#define USIC1_C1_DX1_DX4INS 	6
#define USIC1_C1_DX1_P0_1   	0
#define USIC1_C1_DX2_DX5INS 	6
#define USIC1_C1_DX2_SR0    	5
#define USIC1_C1_DX3_DOUT0  	6
#define USIC1_C1_DX3_DX5INS 	5
#define USIC1_C1_DX3_P0_15  	1
#define USIC1_C1_DX3_P2_4   	2
#define USIC1_C1_DX3_P2_6   	4
#define USIC1_C1_DX4_DX5INS 	5
#define USIC1_C1_DX4_P0_15  	1
#define USIC1_C1_DX4_P2_4   	2
#define USIC1_C1_DX4_P2_6   	4
#define USIC1_C1_DX4_SCLKOUT	6
#define USIC1_C1_DX5_P0_14  	1
#define USIC1_C1_DX5_P2_3   	2
#define USIC1_C1_DX5_P2_5   	3
#define USIC1_C1_DX5_P2_7   	4
#define USIC1_C1_DX5_SELO0  	6
#endif

#endif /* XMC1_USIC_MAP_H */
